@@ -1,5 +1,5 @@
 contourview.list <- function(model,
-        center = NULL,
+        center = NULL, axis = NULL,
         npoints = 20,
         col_points = "red",
         col_surf = "blue",
@@ -21,7 +21,12 @@ contourview.list <- function(model,
         if (D != 2) stop("Section center in 'section' required for >2-D model.")
     }
     
+    if (is.null(axis)) {
     axis <- t(combn(D, 2))
+    } else {
+        ## added by YD for the vector case
+        axis <- matrix(axis, ncol = 2)
+    }
     
     if (is.null(mfrow) && (D>2)) {
         nc <- round(sqrt(nrow(axis)))
@@ -72,7 +77,7 @@ contourview.list <- function(model,
     
     ## Each 'id' will produce a RGL plot
     for (id in 1:dim(axis)[1]) {
-        if (D>2) screen(id)
+        if (D>2) screen(id, new=!add)
         
         d <- axis[id, ]
         
@@ -123,11 +128,11 @@ contourview.list <- function(model,
             xlim <- c(.split.screen.lim[id,1],.split.screen.lim[id,2])
             ylim <- c(.split.screen.lim[id,3],.split.screen.lim[id,4])
             contour(x = xd1,y = xd2, z = yd_mean,
-                    xlab = "", ylab = "", 
                     xlim = xlim, ylim = ylim, zlim = zlim, 
                     col = col_surf, 
                     nlevels = nlevels,
                     levels = pretty(y_mean,nlevels),
+                    add=TRUE,
                     ...)
         } else {
             .split.screen.lim[id,] <<- matrix(c(xlim[1],xlim[2],ylim[1],ylim[2]),nrow=1)
