@@ -1,16 +1,16 @@
 sectionview.list <- function(model,
-        center = NULL,
-        npoints = 100,
-        col_points = "red",
-        col_surf = "blue",
-        bg_blend = 5,
-        mfrow = NULL,
-        Xname = NULL, yname = NULL,
-        Xscale = 1, yscale = 1,
-        xlim = NULL, ylim = NULL,
-        title = NULL,
-        add = FALSE,
-        ...) {
+                             center = NULL, axis = NULL,
+                             npoints = 100,
+                             col_points = "red",
+                             col_surf = "blue",
+                             bg_blend = 5,
+                             mfrow = NULL,
+                             Xname = NULL, yname = NULL,
+                             Xscale = 1, yscale = 1,
+                             xlim = NULL, ylim = NULL,
+                             title = NULL,
+                             add = FALSE,
+                             ...) {
     
     D <- length(model$data$X)
     
@@ -18,6 +18,13 @@ sectionview.list <- function(model,
         if (D != 1) stop("Section center in 'section' required for >1-D model.")
     }
     
+    if (is.null(axis)) {
+        axis <- matrix(1:D, ncol = 1)
+    } else {
+        ## added by YD for the vector case
+        axis <- matrix(axis, ncol = 1)
+    }
+    
     if (is.null(mfrow) && (D>1)) {
         nc <- round(sqrt(D))
         nl <- ceiling(D/nc)
@@ -58,8 +65,10 @@ sectionview.list <- function(model,
     ## try to find a good formatted value 'fcenter' for 'center'
     fcenter <- tryFormat(x = center, drx = drx)
     
-    for (d in 1:D) {
-        if (D>1) screen(d)
+    for (id in 1:dim(axis)[1]) {
+        if (D>1) screen(id, new=!add)
+        
+        d <- axis[id,]        
         
         xdmin <- rx["min", d]
         xdmax <- rx["max", d]
@@ -90,21 +99,26 @@ sectionview.list <- function(model,
             # re-use global settings for limits of this screen
             xlim <- c(.split.screen.lim[d,1],.split.screen.lim[d,2])
             ylim <- c(.split.screen.lim[d,3],.split.screen.lim[d,4])
-            plot(xd, y_mean,
-                    xlab = "", ylab = "",
-                    xlim = xlim, ylim = ylim, 
-                    type = "l",
-                    col = col_surf,
-                    add = TRUE,
-                    ...)
+            if (D>1) {
+                plot(xd, y_mean,
+                     xlim=xlim, ylim=ylim,
+                     type = "l",
+                     col = col_surf,
+                     ...)
+            } else { # not using screen(), so need for a non reset plotting method
+                lines(xd, y_mean,
+                      xlim=xlim, ylim=ylim,
+                      col = col_surf,
+                      ...)
+            }
         } else {
             .split.screen.lim[d,] <<- matrix(c(xlim[1],xlim[2],ylim[1],ylim[2]),nrow=1)
             plot(xd, y_mean,
-                xlab = Xname[d], ylab = yname,
-                ylim = ylim, main = title_d,
-                type = "l",
-                col = col_surf,
-                ...)
+                 xlab = Xname[d], ylab = yname,
+                 ylim = ylim, main = title_d,
+                 type = "l",
+                 col = col_surf,
+                 ...)
             if(D>1) abline(v=center[d],col='black',lty=2)
         }
         
@@ -113,12 +127,12 @@ sectionview.list <- function(model,
         if (D>1) {
             
             xrel <- scale(x = as.matrix(X_doe),
-                    center = center,
-                    scale = rx["max", ] - rx["min", ])
+                          center = center,
+                          scale = rx["max", ] - rx["min", ])
             
             alpha <- apply(X = xrel[ , -d, drop = FALSE],
-                    MARGIN = 1,
-                    FUN = function(x) (1 - (sqrt(sum(x^2)/D)))^bg_blend)
+                           MARGIN = 1,
+                           FUN = function(x) (1 - (sqrt(sum(x^2)/D)))^bg_blend)
             
             ##   for (i in 1:n) {
             ##         xrel = data.frame(((X_doe[i,] - center) / (xmax - xmin)))
@@ -132,9 +146,9 @@ sectionview.list <- function(model,
         ## modif YD : col
         col1 <- fade(color = col_points, alpha = alpha)
         points(X_doe[ , d], y_doe,
-                col = col1,
-                ## col = rgb(1, 1-alpha, 1-alpha, alpha),
-                pch = 20)
+               col = col1,
+               ## col = rgb(1, 1-alpha, 1-alpha, alpha),
+               pch = 20)
         
     }
     
